==> libsyncml_0.4.6.orig.tar.gz: libsyncml-0.4.6/libsyncml/sml_elements_internals.h <==
/*
 * libsyncml - A syncml protocol implementation
 * Copyright (C) 2005  Armin Bauer <armin.bauer@opensync.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; version 
 * 2.1 of the License.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 *
 */

#ifndef _SML_ELEMENTS_INTERNALS_H_
#define _SML_ELEMENTS_INTERNALS_H_

#include <libxml/xmlreader.h>

struct SmlAnchor {
	char *next;
	char *last;
};

struct SmlLocation {
	gint refCount;
	char *locURI;
	char *locName;
};

struct SmlItem {
	gint refCount;
	
	SmlLocation *source;
	SmlLocation *target;
	SmlAnchor *anchor;
	
	xmlBuffer *buffer;
	
	unsigned int size;
	
	char *contenttype;
	SmlBool moreData;
	
	SmlBool disabled;
	/** If set to true, libsyncml will omit the cdata tags */
	SmlBool raw;
};

struct SmlMapItem {
	gint refCount;
	SmlLocation *source;
	SmlLocation *target;
};

struct SmlHeader {
	char *sessionID;
	SmlProtocolVersion version;
	SmlProtocolType protocol;
	SmlLocation *source;
	SmlLocation *target;
	unsigned int messageID;
	unsigned int maxmsgsize;
	unsigned int maxobjsize;
	char *emi;
};

struct SmlCred {
	SmlFormatType format;
	SmlAuthType type;
	char *data;
	gint refCount;
	char *locName;
};

struct SmlChal {
	SmlFormatType format;
	SmlAuthType type;
	char *nonce;
};

#endif //_SML_ELEMENTS_INTERNALS_H_

==> libsyncml_0.5.4.orig.tar.gz: libsyncml-0.5.4/libsyncml/sml_elements_internals.h <==
/*
 * libsyncml - A syncml protocol implementation
 * Copyright (C) 2005  Armin Bauer <armin.bauer@opensync.org>
 * Copyright (C) 2007-2009  Michael Bell <michael.bell@opensync.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 *
 */

/**
 * @defgroup SmlElementsPrivate SyncML Elements Internals
 * @ingroup PrivateLowLevelAPI
 * @brief The private part
 * 
 */
/*@{*/

#ifndef _SML_ELEMENTS_INTERNALS_H_
#define _SML_ELEMENTS_INTERNALS_H_

#include <libxml/xmlreader.h>

struct SmlAnchor {
	char *next;
	char *last;
};

struct SmlLocation {
	gint refCount;
	char *locURI;
	char *locName;
};

struct SmlItem {
	gint refCount;
	
	SmlLocation *source;
	SmlLocation *target;
	SmlLocation *sourceParent;
	SmlLocation *targetParent;
	SmlAnchor *anchor;
	
	xmlBuffer *buffer;
	
	unsigned int size;
	
	char *contenttype;
	SmlBool moreData;
	
	SmlBool disabled;
	/** If set to true, libsyncml will omit the cdata tags */
	SmlBool raw;
};

struct SmlMapItem {
	gint refCount;
	SmlLocation *source;
	SmlLocation *target;
};

struct SmlHeader {
	char *sessionID;
	SmlProtocolVersion version;
	SmlProtocolType protocol;
	SmlLocation *source;
	SmlLocation *target;
	char *responseURI;
	SmlBool noResponse;
	unsigned int messageID;
	unsigned int maxmsgsize;
	unsigned int maxobjsize;
	char *emi;
};

struct SmlCred {
	SmlFormatType format;
	SmlAuthType type;
	char *data;
	gint refCount;
	char *username;
	char *password;
};

struct SmlChal {
	SmlFormatType format;
	SmlAuthType type;
	char *nonce_plain;
	unsigned int nonce_length;
	char *nonce_b64;
	gint refCount;
};

void smlLocationSetURI(SmlLocation *loc, const char *uri);

#endif //_SML_ELEMENTS_INTERNALS_H_

/*@}*/
